@@ -51,8 +51,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define-module (gnucash report standard-reports trial-balance))
-(use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
-(use-modules (gnucash printf))
+(use-modules (gnucash utilities)) 
 (use-modules (gnucash gnc-module))
 (use-modules (gnucash gettext))
 
@@ -135,6 +134,47 @@
 (define optname-show-rates (N_ "Show Exchange Rates"))
 (define opthelp-show-rates (N_ "Show the exchange rates used."))
 
+
+;; utility to assist with double-column balance tables
+;; a request is made with the <req> argument
+;; <req> may currently be 'entry|'debit-q|'credit-q|'zero-q|'debit|'credit
+;; 'debit-q|'credit-q|'zero-q tests the sign of the balance
+;; 'side returns 'debit or 'credit, the column in which to display
+;; 'debt|'credit return the entry, if appropriate, or #f
+(define (double-col
+	 req signed-balance report-commodity exchange-fn show-comm?)
+  (let* ((sum (and signed-balance
+		   (gnc:sum-collector-commodity
+		    signed-balance
+		    report-commodity
+		    exchange-fn)))
+	 (amt (and sum (gnc:gnc-monetary-amount sum)))
+	 (neg? (and amt (negative? amt)))
+	 (bal (if neg?
+		  (let ((bal (gnc:make-commodity-collector)))
+		    (bal 'minusmerge signed-balance #f)
+		    bal)
+		  signed-balance))
+	 (bal-sum (gnc:sum-collector-commodity
+		   bal
+		   report-commodity
+		   exchange-fn))
+	 (balance
+	  (if (gnc:uniform-commodity? bal report-commodity)
+	      (if (zero? amt) #f bal-sum)
+	      (if show-comm?
+		  (gnc-commodity-table bal report-commodity exchange-fn)
+		  bal-sum))))
+    (car (assoc-ref
+	  (list
+	   (list 'entry balance)
+	   (list 'debit (if neg? #f balance))
+	   (list 'credit (if neg? balance #f))
+	   (list 'zero-q (if neg? #f (if balance #f #t)))
+	   (list 'debit-q (if neg? #f (if balance #t #f)))
+	   (list 'credit-q (if neg? #t #f)))
+	  req))))
+
 ;; options generator
 (define (trial-balance-options-generator)
   (let* ((options (gnc:new-options))
@@ -280,6 +320,57 @@
     
     options))
 
+(define (account-get-pos-trans-total-interval
+	 account-list type start-date end-date)
+  (let* ((str-query (qof-query-create-for-splits))
+	 (sign-query (qof-query-create-for-splits))
+	 (total-query #f)
+	 (get-val (lambda (alist key)
+		    (let ((lst (assoc-ref alist key)))
+		      (and lst (car lst)))))
+	 (matchstr (get-val type 'str))
+	 (case-sens (and (get-val type 'cased) #t))
+	 (regexp (and (get-val type 'regexp) #t))
+	 (pos? (and (get-val type 'positive) #t))
+         (total (gnc:make-commodity-collector)))
+    (qof-query-set-book str-query (gnc-get-current-book))
+    (qof-query-set-book sign-query (gnc-get-current-book))
+    (gnc:query-set-match-non-voids-only! str-query (gnc-get-current-book))
+    (gnc:query-set-match-non-voids-only! sign-query (gnc-get-current-book))
+    (xaccQueryAddAccountMatch str-query account-list QOF-GUID-MATCH-ANY QOF-QUERY-AND)
+    (xaccQueryAddAccountMatch sign-query account-list QOF-GUID-MATCH-ANY QOF-QUERY-AND)
+    (xaccQueryAddDateMatchTT str-query
+                             (and start-date #t) (or start-date 0)
+                             (and end-date #t) (or end-date 0)
+                             QOF-QUERY-AND)
+    (xaccQueryAddDateMatchTT sign-query
+                             (and start-date #t) (or start-date 0)
+                             (and end-date #t) (or end-date 0)
+                             QOF-QUERY-AND)
+    (xaccQueryAddDescriptionMatch
+     str-query matchstr case-sens regexp QOF-COMPARE-CONTAINS QOF-QUERY-AND)
+    (set! total-query
+      ;; this is a tad inefficient, but its a simple way to accomplish
+      ;; description match inversion...
+      (if pos?
+          (qof-query-merge-in-place sign-query str-query QOF-QUERY-AND)
+          (let ((inv-query (qof-query-invert str-query)))
+            (qof-query-merge-in-place
+             sign-query inv-query QOF-QUERY-AND)
+            qof-query-destroy inv-query)))
+    (qof-query-destroy str-query)
+
+    (map
+     (lambda (split)
+	   (let* ((shares (xaccSplitGetAmount split))
+		  (acct-comm (xaccAccountGetCommodity
+			      (xaccSplitGetAccount split))))
+	     (unless (negative? shares)
+               (total 'add acct-comm shares))))
+         (qof-query-run total-query))
+    (qof-query-destroy total-query)
+    total))
+
   ;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; trial-balance-renderer
 ;; set up the document and add the table
@@ -302,9 +393,9 @@
          (start-date-printable (gnc:date-option-absolute-time
 				(get-option gnc:pagename-general
 					    optname-start-date)))
-         (start-date-tp (gnc:timepair-end-day-time
-			 (gnc:timepair-previous-day start-date-printable)))
-         (end-date-tp (gnc:timepair-end-day-time 
+         (start-date (gnc:time64-end-day-time
+			 (gnc:time64-previous-day start-date-printable)))
+         (end-date (gnc:time64-end-day-time 
 		       (gnc:date-option-absolute-time
 			(get-option gnc:pagename-general
 				    optname-end-date))))
@@ -384,26 +475,26 @@
 	 (doc (gnc:make-html-document))
          ;; exchange rates calculation parameters
 	 (exchange-fn
-	  (gnc:case-exchange-fn price-source report-commodity end-date-tp))
+	  (gnc:case-exchange-fn price-source report-commodity end-date))
 	 (terse-period? #t)
 	 (period-for (if terse-period?
 			 (string-append " " (_ "for Period"))
-			 (sprintf #f (string-append ", " (_ "%s to %s"))
-				  (gnc-print-date start-date-printable)
-				  (gnc-print-date end-date-tp))
+			 (format #f (string-append ", " (_ "~a to ~a"))
+				  (qof-print-date start-date-printable)
+				  (qof-print-date end-date))
 			 ))
 	 )
     
     (gnc:html-document-set-title! 
      doc (if (equal? report-variant 'current)
-	     (sprintf #f (string-append "%s %s %s")
+	     (format #f (string-append "~a ~a ~a")
 		      company-name report-title
-		      (gnc-print-date end-date-tp))
-	     (sprintf #f (string-append "%s %s "
-					(_ "For Period Covering %s to %s"))
+		      (qof-print-date end-date))
+	     (format #f (string-append "~a ~a "
+					(_ "For Period Covering ~a to ~a"))
 		      company-name report-title
-		      (gnc-print-date start-date-printable)
-		      (gnc-print-date end-date-tp))
+		      (qof-print-date start-date-printable)
+		      (qof-print-date end-date))
 	     )
      )
     
@@ -442,10 +533,10 @@
 	  ;; with the proper arguments.
 	  ;; (This is used to fill in the Trial Balance columns.)
 	  (define (add-line table label signed-balance)
-	    (let* ((entry (gnc:double-col
+	    (let* ((entry (double-col
 			   'entry signed-balance
 			   report-commodity exchange-fn show-fcur?))
-		   (credit? (gnc:double-col
+		   (credit? (double-col
 			     'credit-q signed-balance
 			     report-commodity exchange-fn show-fcur?))
 		   )
@@ -523,7 +614,7 @@
                       (unrealized-gain-collector (gnc:make-commodity-collector))
                       (cost-fn (gnc:case-exchange-fn 'average-cost
                                                      report-commodity
-                                                     end-date-tp))
+                                                     end-date))
                       (value #f)
                       (cost #f))
 
@@ -533,7 +624,7 @@
                    (lambda (acct)
                      (book-balance 'merge
                                    (gnc:account-get-comm-balance-at-date
-                                    acct end-date-tp #f)
+                                    acct end-date #f)
                      #f))
                    all-accounts)
 
@@ -573,7 +664,7 @@
 	  (set! table-env
 		(list
 		 (list 'start-date #f)
-		 (list 'end-date end-date-tp)
+		 (list 'end-date end-date)
 		 (list 'display-tree-depth
 		       (if (integer? depth-limit) depth-limit #f))
 		 (list 'depth-limit-behavior 'flatten)
@@ -623,31 +714,17 @@
 		(set! parent-headings
 		      (apply append
 			     (map
-			      (if gnc:colspans-are-working-right
-				  (lambda (heading)
-				    (list 
-				     (gnc:make-html-table-cell/size/markup
-				      1 2 "th" heading)
-				     )
-				    )
-				  (lambda (heading)
-				    (list
-				     (gnc:make-html-table-cell/size/markup
-				      1 1 "th" heading)
-				     (gnc:html-make-empty-cell)
-				     )
-				    )
-				  )
+                              (lambda (heading)
+				(list
+				 (gnc:make-html-table-cell/size/markup 1 1 "th" heading)
+				 (gnc:html-make-empty-cell)))
 			      headings)
 			     )
 		      )
 		(gnc:html-table-append-row!
 		 build-table
 		 (append
-		  (if gnc:colspans-are-working-right
-		      (list (gnc:make-html-table-cell/size 1 account-cols #f))
-		      (gnc:html-make-empty-cells account-cols)
-		      )
+                  (gnc:html-make-empty-cells account-cols)
 		  parent-headings)
 		 )
 		(set! header-rows (+ header-rows 1))
@@ -710,7 +787,7 @@
 				  (list 'regexp closing-regexp)
 				  (list 'closing #t)
 				  )
-			    start-date-tp end-date-tp
+			    start-date end-date
 			    ))
 			  (adjusting
 			   (gnc:account-get-trans-type-balance-interval-with-closing
@@ -719,21 +796,21 @@
 				  (list 'cased adjusting-cased)
 				  (list 'regexp adjusting-regexp)
 				  )
-			    start-date-tp end-date-tp
+			    start-date end-date
 			    ))
 			  (is? (member acct all-is-accounts))
 			  (ga-or-is? (or (member acct all-ga-accounts) is?))
 			  (pos-adjusting
 			   (and ga-or-is?
 				adjusting
-				(gnc:account-get-pos-trans-total-interval
+				(account-get-pos-trans-total-interval
 				 group
 				 (list (list 'str adjusting-str)
 				       (list 'cased adjusting-cased)
 				       (list 'regexp adjusting-regexp)
 				       (list 'positive #t)
 				       )
-				 start-date-tp end-date-tp
+				 start-date end-date
 				 )
 				))
 			  (neg-adjusting
@@ -770,7 +847,7 @@
 				      )
 				 (debit 'merge pos-adjusting #f)
 				 (credit 'merge neg-adjusting #f)
-				 (if (gnc:double-col
+				 (if (double-col
 				      'credit-q pre-adjusting-bal
 				      report-commodity exchange-fn show-fcur?)
 				     (credit 'merge pre-adjusting-bal #f)
@@ -840,10 +917,10 @@
 		     neg-unrealized-gain-collector))
 	       (let* ((ug-row (+ header-rows
 				 (gnc:html-acct-table-num-rows acct-table)))
-                      (credit? (gnc:double-col
+                      (credit? (double-col
                                 'credit-q neg-unrealized-gain-collector
                                 report-commodity exchange-fn show-fcur?))
-                      (entry (gnc:double-col
+                      (entry (double-col
                               'entry neg-unrealized-gain-collector
                               report-commodity exchange-fn show-fcur?))
 		      )
@@ -909,14 +986,14 @@
 				     (gross-bal? (list? bal))
 				     (entry (and bal
 						 (not gross-bal?)
-						 (gnc:double-col
+						 (double-col
 						  'entry bal
 						  report-commodity
 						  exchange-fn
 						  show-fcur?)))
 				     (credit? (and bal
 						   (or gross-bal?
-						       (gnc:double-col
+						       (double-col
 							'credit-q bal
 							report-commodity
 							exchange-fn
@@ -937,7 +1014,7 @@
 					      ))
 				     (debit-entry
 				      (and gross-bal?
-					   (gnc:double-col
+					   (double-col
 					    'entry debit
 					    report-commodity
 					    exchange-fn
@@ -945,7 +1022,7 @@
 				      )
 				     (credit-entry
 				      (and gross-bal?
-					   (gnc:double-col
+					   (double-col
 					    'entry credit
 					    report-commodity
 					    exchange-fn
@@ -1051,19 +1128,19 @@
 		(net-bs 'merge bs-debits #f)
 		(net-bs 'minusmerge bs-credits #f)
 		(set! is-entry
-		      (gnc:double-col
+		      (double-col
 		       'entry net-is report-commodity
 		       exchange-fn show-fcur?))
 		(set! is-credit?
-		      (gnc:double-col
+		      (double-col
 		       'credit-q net-is report-commodity
 		       exchange-fn show-fcur?))
 		(set! bs-entry
-		      (gnc:double-col
+		      (double-col
 		       'entry net-bs report-commodity
 		       exchange-fn show-fcur?))
 		(set! bs-credit?
-		      (gnc:double-col
+		      (double-col
 		       'credit-q net-bs report-commodity
 		       exchange-fn show-fcur?))
 		(gnc:html-table-add-labeled-amount-line!
@@ -1096,11 +1173,7 @@
 		 build-table
 		 "primary-subheading"
 		 (append
-		  (if gnc:colspans-are-working-right
-		      (list (gnc:make-html-table-cell/size
-			     1 (+ account-cols (* 2 is-col)) #f))
-		      (gnc:html-make-empty-cells (+ account-cols (* 2 is-col)))
-		      )
+                  (gnc:html-make-empty-cells (+ account-cols (* 2 is-col)))
 		  (list
 		   (tot-abs-amt-cell (if is-credit? tot-is is-debits))
 		   (tot-abs-amt-cell (if is-credit? is-credits tot-is))
@@ -1126,8 +1199,6 @@
 	  (gnc:report-percent-done 100)
 	  
 	  ;; if sending the report to a file, do so now
-	  ;; however, this still doesn't seem to get around the
-	  ;; colspan bug... cf. gnc:colspans-are-working-right
 	  (if filename
 	      (let* ((port (open-output-file filename)))
                 (gnc:display-report-list-item
@@ -1136,9 +1207,7 @@
     
     (gnc:report-finished)
     
-    doc
-    )
-  )
+    doc))
 
 (gnc:define-report 
  'version 1
@@ -1153,4 +1222,3 @@
 		 (trial-balance-renderer report-obj #f filename)))
 
 ;; END
-
