@@ -75,7 +75,7 @@ enum
     PROP_MARKER,        /* Runtime */
 };
 
-typedef struct LotPrivate
+typedef struct GNCLotPrivate
 {
     /* Account to which this lot applies.  All splits in the lot must
      * belong to this account.
@@ -92,22 +92,22 @@ typedef struct LotPrivate
 
     /* traversal marker, handy for preventing recursion */
     unsigned char marker;
-} LotPrivate;
+} GNCLotPrivate;
 
 #define GET_PRIVATE(o) \
-    (G_TYPE_INSTANCE_GET_PRIVATE((o), GNC_TYPE_LOT, LotPrivate))
+    (G_TYPE_INSTANCE_GET_PRIVATE((o), GNC_TYPE_LOT, GNCLotPrivate))
 
 #define gnc_lot_set_guid(L,G)  qof_instance_set_guid(QOF_INSTANCE(L),&(G))
 
 /* ============================================================= */
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GNCLot, gnc_lot, QOF_TYPE_INSTANCE)
+G_DEFINE_TYPE_WITH_PRIVATE(GNCLot, gnc_lot, QOF_TYPE_INSTANCE)
 
 static void
 gnc_lot_init(GNCLot* lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
 
     priv = GET_PRIVATE(lot);
     priv->account = NULL;
@@ -132,7 +132,7 @@ static void
 gnc_lot_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec* pspec)
 {
     GNCLot* lot;
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     gchar *key;
 
     g_return_if_fail(GNC_IS_LOT(object));
@@ -148,16 +148,13 @@ gnc_lot_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec*
         g_value_set_int(value, priv->marker);
         break;
     case PROP_INVOICE:
-        key = GNC_INVOICE_ID "/" GNC_INVOICE_GUID;
-        qof_instance_get_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_get_kvp (QOF_INSTANCE (lot), value, 2, GNC_INVOICE_ID, GNC_INVOICE_GUID);
         break;
     case PROP_OWNER_TYPE:
-        key = GNC_OWNER_ID"/" GNC_OWNER_TYPE;
-        qof_instance_get_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_get_kvp (QOF_INSTANCE (lot), value, 2, GNC_OWNER_ID, GNC_OWNER_TYPE);
         break;
     case PROP_OWNER_GUID:
-        key = GNC_OWNER_ID "/" GNC_OWNER_GUID;
-        qof_instance_get_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_get_kvp (QOF_INSTANCE (lot), value, 2, GNC_OWNER_ID, GNC_OWNER_GUID);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -172,7 +169,7 @@ gnc_lot_set_property (GObject* object,
                       GParamSpec* pspec)
 {
     GNCLot* lot;
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     gchar *key = NULL;
 
     g_return_if_fail(GNC_IS_LOT(object));
@@ -191,16 +188,13 @@ gnc_lot_set_property (GObject* object,
         priv->marker = g_value_get_int(value);
         break;
     case PROP_INVOICE:
-        key = GNC_INVOICE_ID"/" GNC_INVOICE_GUID;
-        qof_instance_set_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_set_kvp (QOF_INSTANCE (lot), value, 2, GNC_INVOICE_ID, GNC_INVOICE_GUID);
         break;
     case PROP_OWNER_TYPE:
-        key = GNC_OWNER_ID "/" GNC_OWNER_TYPE;
-        qof_instance_set_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_set_kvp (QOF_INSTANCE (lot), value, 2, GNC_OWNER_ID, GNC_OWNER_TYPE);
         break;
     case PROP_OWNER_GUID:
-        key = GNC_OWNER_ID "/" GNC_OWNER_GUID;
-        qof_instance_set_kvp (QOF_INSTANCE (lot), key, value);
+        qof_instance_set_kvp (QOF_INSTANCE (lot), value, 2, GNC_OWNER_ID, GNC_OWNER_GUID);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -218,8 +212,6 @@ gnc_lot_class_init(GNCLotClass* klass)
     gobject_class->get_property = gnc_lot_get_property;
     gobject_class->set_property = gnc_lot_set_property;
 
-    g_type_class_add_private(klass, sizeof(LotPrivate));
-
     g_object_class_install_property(
         gobject_class,
         PROP_IS_CLOSED,
@@ -283,7 +275,7 @@ static void
 gnc_lot_free(GNCLot* lot)
 {
     GList *node;
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return;
 
     ENTER ("(lot=%p)", lot);
@@ -370,7 +362,7 @@ gnc_lot_get_book (GNCLot *lot)
 gboolean
 gnc_lot_is_closed (GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return TRUE;
     priv = GET_PRIVATE(lot);
     if (0 > priv->is_closed) gnc_lot_get_balance (lot);
@@ -380,7 +372,7 @@ gnc_lot_is_closed (GNCLot *lot)
 Account *
 gnc_lot_get_account (const GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return NULL;
     priv = GET_PRIVATE(lot);
     return priv->account;
@@ -391,7 +383,7 @@ gnc_lot_set_account(GNCLot* lot, Account* account)
 {
     if (lot != NULL)
     {
-        LotPrivate* priv;
+        GNCLotPrivate* priv;
         priv = GET_PRIVATE(lot);
         priv->account = account;
     }
@@ -400,7 +392,7 @@ gnc_lot_set_account(GNCLot* lot, Account* account)
 void
 gnc_lot_set_closed_unknown(GNCLot* lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (lot != NULL)
     {
         priv = GET_PRIVATE(lot);
@@ -411,7 +403,7 @@ gnc_lot_set_closed_unknown(GNCLot* lot)
 SplitList *
 gnc_lot_get_split_list (const GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return NULL;
     priv = GET_PRIVATE(lot);
     return priv->splits;
@@ -419,7 +411,7 @@ gnc_lot_get_split_list (const GNCLot *lot)
 
 gint gnc_lot_count_splits (const GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return 0;
     priv = GET_PRIVATE(lot);
     return g_list_length (priv->splits);
@@ -433,7 +425,7 @@ gnc_lot_get_title (const GNCLot *lot)
 {
     GValue v = G_VALUE_INIT;
     if (!lot) return NULL;
-    qof_instance_get_kvp (QOF_INSTANCE (lot), "/title", &v);
+    qof_instance_get_kvp (QOF_INSTANCE (lot), &v, 1, "title");
     if (G_VALUE_HOLDS_STRING (&v))
         return g_value_get_string (&v);
     return NULL;
@@ -444,7 +436,7 @@ gnc_lot_get_notes (const GNCLot *lot)
 {
     GValue v = G_VALUE_INIT;
     if (!lot) return NULL;
-    qof_instance_get_kvp (QOF_INSTANCE (lot), "/notes", &v);
+    qof_instance_get_kvp (QOF_INSTANCE (lot), &v, 1, "notes");
     if (G_VALUE_HOLDS_STRING (&v))
         return g_value_get_string (&v);
     return NULL;
@@ -458,7 +450,7 @@ gnc_lot_set_title (GNCLot *lot, const char *str)
     qof_begin_edit(QOF_INSTANCE(lot));
     g_value_init (&v, G_TYPE_STRING);
     g_value_set_string (&v, str);
-    qof_instance_set_kvp (QOF_INSTANCE (lot), "/title", &v);
+    qof_instance_set_kvp (QOF_INSTANCE (lot), &v, 1, "title");
     qof_instance_set_dirty(QOF_INSTANCE(lot));
     gnc_lot_commit_edit(lot);
 }
@@ -471,7 +463,7 @@ gnc_lot_set_notes (GNCLot *lot, const char *str)
     qof_begin_edit(QOF_INSTANCE(lot));
     g_value_init (&v, G_TYPE_STRING);
     g_value_set_string (&v, str);
-    qof_instance_set_kvp (QOF_INSTANCE (lot), "/notes", &v);
+    qof_instance_set_kvp (QOF_INSTANCE (lot), &v, 1, "notes");
     qof_instance_set_dirty(QOF_INSTANCE(lot));
     gnc_lot_commit_edit(lot);
 }
@@ -481,7 +473,7 @@ gnc_lot_set_notes (GNCLot *lot, const char *str)
 gnc_numeric
 gnc_lot_get_balance (GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     GList *node;
     gnc_numeric zero = gnc_numeric_zero();
     gnc_numeric baln = zero;
@@ -524,7 +516,7 @@ void
 gnc_lot_get_balance_before (const GNCLot *lot, const Split *split,
                             gnc_numeric *amount, gnc_numeric *value)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     GList *node;
     gnc_numeric zero = gnc_numeric_zero();
     gnc_numeric amt = zero;
@@ -573,7 +565,7 @@ gnc_lot_get_balance_before (const GNCLot *lot, const Split *split,
 void
 gnc_lot_add_split (GNCLot *lot, Split *split)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     Account * acc;
     if (!lot || !split) return;
     priv = GET_PRIVATE(lot);
@@ -625,7 +617,7 @@ gnc_lot_add_split (GNCLot *lot, Split *split)
 void
 gnc_lot_remove_split (GNCLot *lot, Split *split)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot || !split) return;
     priv = GET_PRIVATE(lot);
 
@@ -652,7 +644,7 @@ gnc_lot_remove_split (GNCLot *lot, Split *split)
 Split *
 gnc_lot_get_earliest_split (GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     if (!lot) return NULL;
     priv = GET_PRIVATE(lot);
     if (! priv->splits) return NULL;
@@ -664,7 +656,7 @@ gnc_lot_get_earliest_split (GNCLot *lot)
 Split *
 gnc_lot_get_latest_split (GNCLot *lot)
 {
-    LotPrivate* priv;
+    GNCLotPrivate* priv;
     SplitList *node;
 
     if (!lot) return NULL;
